@@ -11,7 +11,7 @@ class LivePredictMeta(BaseModel):
 
 
 class Model(BaseModel):
-    endpoint: str
+    endpoint_id: str
     type: str
 
     class Config:
