@@ -10,7 +10,7 @@ from captur_ml_sdk.dtypes.interfaces.validators import (
     check_images_or_imagesfile_is_included,
     enforce_mutual_exclusivity_between_images_and_imagesfile
 )
-from captur_ml_sdk.dtypes.utils import get_image_components
+from captur_ml_sdk.utils import get_image_components
 
 
 class TrainMeta(BaseModel):
@@ -21,13 +21,16 @@ class TrainMeta(BaseModel):
 class BaseMdl(BaseModel):
     name: str
     version: Optional[str] = "HEAD"
+    dataset_id: str
 
-    root_validator(check_model_exists)
+    _model_exists = root_validator(check_model_exists, allow_reuse=True)
 
 
 class Model(BaseModel):
     name: str
     base_model: Optional[BaseMdl]
+    include_data: str
+    exclude_classes: Optional[List[str]]
 
 
 class Data(BaseModel):
@@ -37,7 +40,7 @@ class Data(BaseModel):
     class Config:
         arbitrary_types_allowed = True
 
-    @ validator('imagesfile')
+    @validator('imagesfile')
     def check_imagesfile_has_correct_components(cls, v):
         try:
             get_image_components(v, ".csv")
@@ -45,11 +48,14 @@ class Data(BaseModel):
             raise ValueError(str(e))
         return v
 
-    validator("imagesfile")(ensure_file_exists)
+    _check_imagesfile = validator(
+        "imagesfile", allow_reuse=True)(ensure_file_exists)
 
-    root_validator(check_images_or_imagesfile_is_included)
+    _check_images_or_imagesfile = root_validator(
+        check_images_or_imagesfile_is_included, allow_reuse=True)
 
-    root_validator(enforce_mutual_exclusivity_between_images_and_imagesfile)
+    _images_and_imagesfile_mutual_exclusivity = root_validator(
+        enforce_mutual_exclusivity_between_images_and_imagesfile, allow_reuse=True)
 
 
 class ModelTrainRequest(BaseModel):
