@@ -1,4 +1,6 @@
-from captur_ml_sdk.utils.gcp_functions import get_requested_model_id, check_file_exists
+from captur_ml_sdk.utils.gcp_functions import (
+    get_requested_model_id, check_file_exists, get_model_type_from_gcp
+)
 
 from captur_ml_sdk.dtypes.exceptions import (
     ModelNotFoundError, VersionNotFoundError, ModelHasNoLiveVersionsError
@@ -26,6 +28,16 @@ def check_model_exists(cls, values):
     return values
 
 
+def fetch_model_type(cls, values):
+    name = values.get("name")
+    try:
+        model_type = get_model_type_from_gcp(name)
+        values["type"] = model_type
+    except ModelNotFoundError as e:
+        raise TypeError(str(e))
+    return values
+
+
 def ensure_file_exists(cls, v):
     if v:
         if not check_file_exists(v):
